<template>
    <div :class="['map-target', !isSub ? 'isSub' : '']">
        <div class="map-tip-container" v-if="isSub">
            <div class="map-container" :element-loading-background="loadingColor" v-loading="loading">
                <div :id="CQId"></div>
                <div :id="main9Id">
                    <div :class="['ljxq', `grade-${ljxqGrade}`]" @click="goToSub('ljxq')">
                        <i class="dot"></i>
                    </div>
                    <div :class="['gxq', `grade-${gxqGrade}`]" @click="goToSub('gxq')">
                        <i class="dot"></i>
                    </div>
                </div>
            </div>
            <div class="fdgz">
                <!-- {{
                    quarter === 2
                        ? `本季以20（平均值）为中线，上下各采取等分法分为两档。`
                        : `以改革首创和全市推广的次数为评价内容，当季以平均值（{{ meanObj.cityNumAvg }}）为中线，上下各等分两档。`
                }} -->
            </div>
            <div class="map-tip">
                <div class="tip-item">
                    <div class="level-title">A档</div>
                    <div class="tip-text">
                        &nbsp;≥平均值（{{
        meanObj.digitRateAvg
    }}分）<br />等分为两档，第1档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">B档</div>
                    <div class="tip-text">
                        &nbsp;≥平均值（{{
            meanObj.digitRateAvg
        }}分）<br />等分为两档，第2档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">C档</div>
                    <div class="tip-text">
                        ＜平均值（{{
            meanObj.digitRateAvg
        }}分）<br />等分为两档，第1档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">D档</div>
                    <div class="tip-text">
                        ＜平均值（{{
            meanObj.digitRateAvg
        }}分）<br />等分为两档，第2档
                    </div>
                </div>
            </div>
        </div>
        <div class="text-tip">
            <div v-if="!isSub">此项指标只展示，不分档计分。</div>
            <div v-if="quarter === 3">
                (本季度只展示区县一体化治理智治平台试点镇街运行使用情况,由网格员活跃率、重点对象关注覆盖率、网格事件按期办理率、网格任务完成率构成，满分为10分。)
            </div>
        </div>
        <div class="list-container">
            <air-table @loadComplete="loadComplete" :data="tableData" :tableColumn="tableColumn" :lsFd="lsFd"
                :isSub="isSub"></air-table>
        </div>
        <!-- 名录库按钮 -->
        <!-- <div class="detail-btn" @click="handleDetail">名录库</div> -->
    </div>
</template>

<script>
import airTable from './airTable.vue'
import mapTargetMixin from '@/mixins/mapTargetMixin.js'
export default {
    mixins: [mapTargetMixin],
    components: {
        airTable,
    },
    props: {
        options: {
            type: Object,
            default: () => {
                return {}
            },
        },
        CQId: {
            type: String,
            default: 'cq-contianer_9',
        },
        main9Id: {
            type: String,
            default: 'main9-contianer_9',
        },
        isClick: {
            type: Boolean,
            default: true,
        },
    },
    data() {
        return {
            tableColumn: [
                { label: '区县', prop: 'unitName' },
                { label: '', prop: 'digitRate' },
            ],
            typeNum: 'digitRate',
            typeGrade: 'digitGrade',
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.setIsSub()
        this.setTableColumn()
        this.initData()
        // this.$bus.$off('changeDate') // 避免重复触发
        this.$bus.$on('changeDate', () => {
            this.setIsSub()
            this.setTableColumn()
            this.initData()
        })
        this.$root.$on('resize', () => {
            this.resize(500)
        })
    },
    methods: {
        getData() {
            this.setIsSub()
            this.setTableColumn()
            this.initData()
        },
        setIsSub() {
            let { year, quarter } = JSON.parse(
                sessionStorage.getItem('searchDate')
            )
            if (year === 2023 && quarter < 4 && quarter !== 0) {
                this.isSub = false
            } else {
                this.isSub = true
            }
            this.setLsFd()
        },
        setLsFd() {
            let { year, quarter } = JSON.parse(
                sessionStorage.getItem('searchDate')
            )
            this.quarter = quarter
            this.year = year
            if (
                (year === 2023 &&
                    (quarter === 4 || quarter === 0) &&
                    this.isSub) ||
                year > 2023
            ) {
                this.lsFd = { A: true, B: true, C: true, D: true }
            } else if (!this.isSub) {
                this.lsFd = { A: true, B: false, C: false, D: false }
            }
        },
        // 插入表头
        setTableColumn() {
            let { year, quarter } = JSON.parse(
                sessionStorage.getItem('searchDate')
            )
            this.year = year
            this.quarter = quarter
            if (year === 2023 && quarter === 3) {
                this.tableColumn = [
                    { label: '区县', prop: 'unitName' },
                    { label: '实际值\n(分)', prop: 'digitRate' },
                ]
            } else if (year === 2023 && (quarter === 1 || quarter === 2)) {
                this.tableColumn = [
                    { label: '区县', prop: 'unitName' },
                    { label: '实际值\n(%)', prop: 'digitRate' },
                ]
            } else {
                this.tableColumn = [
                    { label: '排名', prop: 'digitSn' },
                    { label: '区县', prop: 'unitName' },
                    { label: '实际值\n(分)', prop: 'digitRate' },
                    { label: '得分', prop: 'digitScore' },
                ]
            }
        },
        handleDetail() {
            this.$router.push({
                path: '/DetailComponent',
                name: 'DetailComponent',
                query: {
                    comp: 'districtDirectory',
                },
            })
        },
    },
}
</script>

<style lang="scss" scoped>
@import './target.scss';

.text-tip {
    letter-spacing: 2px;
    position: absolute;
    width: 400PX;
    left: 20px;
    /* top: 0; */
    font-size: 18PX;
    color: #fff;

    div {
        width: fit-content;
        letter-spacing: 2px;
        font-size: 18PX;
    }

    :last-child {
        position: absolute;
        left: 0;
    }
}

.map-tip {
    bottom: 0;
}

.map-target {
    padding: 30PX 35PX;
}

.level-container {
    display: flex;
    flex-direction: column;
    height: 100%;
    // height: 765px;
    flex-wrap: wrap;
    row-gap: 0;
    align-content: flex-end;

    >* {
        width: 30.33%;
        // flex: 1;
        font-family: '微软雅黑', sans-serif !important;
    }

    .level-title {
        display: flex;
        align-items: center;
        justify-content: center;
        text-align: center;
        font-size: 24PX;
        font-weight: bold;
        // height: calc(100% / 17);
        height: 32PX;
        line-height: 32PX;
        margin-top: 20PX;

        &:last-child {
            margin-bottom: 5px;
        }
    }

    .level-title-A {
        margin-top: 0;
        background-color: #398C8F;
    }

    .level-title-B {
        background-color: #1970c1;
    }

    .level-title-C {
        background-color: #A3A355;
    }

    .level-title-D {
        background-color: #B0825C;
    }

    .level-title-E {
        background-color: #9B4E55;
    }

    .level-header,
    .level-content-item {
        align-items: center;
        // line-height: 30px;
        margin: 0;
        height: calc(100% / 18);

        span {
            text-align: center;
            font-size: 18px;
            // display: inline-block;
            // padding: 12px 2px;
            flex: 1;
            text-align: center;
            // color:#b1e3ff;

            &:first-child {
                flex: 1.3;
            }

            &:last-child {
                flex: 1;
            }
        }

    }
}
</style>
